# pulp_ansible_client

PulpAnsibleClient - the Ruby gem for the Pulp 3 API

Fetch, Upload, Organize, and Distribute Software Packages

This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v3
- Package version: 0.20.2
- Build package: org.openapitools.codegen.languages.RubyClientCodegen
For more information, please visit [https://pulpproject.org](https://pulpproject.org)

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build pulp_ansible_client.gemspec
```

Then either install the gem locally:

```shell
gem install ./pulp_ansible_client-0.20.2.gem
```

(for development, run `gem install --dev ./pulp_ansible_client-0.20.2.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'pulp_ansible_client', '~> 0.20.2'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/GIT_USER_ID/GIT_REPO_ID, then add the following in the Gemfile:

    gem 'pulp_ansible_client', :git => 'https://github.com/GIT_USER_ID/GIT_REPO_ID.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:

```ruby
# Load the gem
require 'pulp_ansible_client'

# Setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR_USERNAME'
  config.password = 'YOUR_PASSWORD'
end

api_instance = PulpAnsibleClient::AnsibleCollectionsApi.new
ansible_collection_href = 'ansible_collection_href_example' # String | 
nested_role = PulpAnsibleClient::NestedRole.new # NestedRole | 

begin
  #Add a role
  result = api_instance.add_role(ansible_collection_href, nested_role)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling AnsibleCollectionsApi->add_role: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *http://pulp*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PulpAnsibleClient::AnsibleCollectionsApi* | [**add_role**](docs/AnsibleCollectionsApi.md#add_role) | **POST** {ansible_collection_href}add_role/ | Add a role
*PulpAnsibleClient::AnsibleCollectionsApi* | [**list**](docs/AnsibleCollectionsApi.md#list) | **GET** /pulp/api/v3/ansible/collections/ | List collections
*PulpAnsibleClient::AnsibleCollectionsApi* | [**list_roles**](docs/AnsibleCollectionsApi.md#list_roles) | **GET** {ansible_collection_href}list_roles/ | List roles
*PulpAnsibleClient::AnsibleCollectionsApi* | [**my_permissions**](docs/AnsibleCollectionsApi.md#my_permissions) | **GET** {ansible_collection_href}my_permissions/ | List user permissions
*PulpAnsibleClient::AnsibleCollectionsApi* | [**remove_role**](docs/AnsibleCollectionsApi.md#remove_role) | **POST** {ansible_collection_href}remove_role/ | Remove a role
*PulpAnsibleClient::AnsibleCollectionsApi* | [**upload_collection**](docs/AnsibleCollectionsApi.md#upload_collection) | **POST** /ansible/collections/ | Upload a collection
*PulpAnsibleClient::AnsibleCopyApi* | [**copy_content**](docs/AnsibleCopyApi.md#copy_content) | **POST** /pulp/api/v3/ansible/copy/ | Copy content
*PulpAnsibleClient::ApiCollectionsApi* | [**get**](docs/ApiCollectionsApi.md#get) | **GET** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiCollectionsApi* | [**post**](docs/ApiCollectionsApi.md#post) | **POST** {ansible_collection_href}api/v2/collections/ | 
*PulpAnsibleClient::ApiRolesApi* | [**get**](docs/ApiRolesApi.md#get) | **GET** {ansible_role_href}api/v1/roles/ | 
*PulpAnsibleClient::CollectionImportApi* | [**read**](docs/CollectionImportApi.md#read) | **GET** {ansible_collection_import_href} | Inspect a collection import
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**create**](docs/ContentCollectionDeprecationsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_deprecations/ | Create an ansible collection deprecated
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**list**](docs/ContentCollectionDeprecationsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_deprecations/ | List ansible collection deprecateds
*PulpAnsibleClient::ContentCollectionDeprecationsApi* | [**read**](docs/ContentCollectionDeprecationsApi.md#read) | **GET** {ansible_ansible_collection_deprecated_href} | Inspect an ansible collection deprecated
*PulpAnsibleClient::ContentCollectionMarksApi* | [**create**](docs/ContentCollectionMarksApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_marks/ | Create a collection version mark
*PulpAnsibleClient::ContentCollectionMarksApi* | [**list**](docs/ContentCollectionMarksApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_marks/ | List collection version marks
*PulpAnsibleClient::ContentCollectionMarksApi* | [**read**](docs/ContentCollectionMarksApi.md#read) | **GET** {ansible_collection_version_mark_href} | Inspect a collection version mark
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**create**](docs/ContentCollectionSignaturesApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_signatures/ | Create a collection version signature
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**list**](docs/ContentCollectionSignaturesApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_signatures/ | List collection version signatures
*PulpAnsibleClient::ContentCollectionSignaturesApi* | [**read**](docs/ContentCollectionSignaturesApi.md#read) | **GET** {ansible_collection_version_signature_href} | Inspect a collection version signature
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**create**](docs/ContentCollectionVersionsApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_versions/ | Create a collection version
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**list**](docs/ContentCollectionVersionsApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_versions/ | List collection versions
*PulpAnsibleClient::ContentCollectionVersionsApi* | [**read**](docs/ContentCollectionVersionsApi.md#read) | **GET** {ansible_collection_version_href} | Inspect a collection version
*PulpAnsibleClient::ContentNamespacesApi* | [**avatar**](docs/ContentNamespacesApi.md#avatar) | **GET** {ansible_ansible_namespace_metadata_href}avatar/ | 
*PulpAnsibleClient::ContentNamespacesApi* | [**list**](docs/ContentNamespacesApi.md#list) | **GET** /pulp/api/v3/content/ansible/namespaces/ | List ansible namespace metadatas
*PulpAnsibleClient::ContentNamespacesApi* | [**read**](docs/ContentNamespacesApi.md#read) | **GET** {ansible_ansible_namespace_metadata_href} | Inspect an ansible namespace metadata
*PulpAnsibleClient::ContentRolesApi* | [**create**](docs/ContentRolesApi.md#create) | **POST** /pulp/api/v3/content/ansible/roles/ | Create a role
*PulpAnsibleClient::ContentRolesApi* | [**list**](docs/ContentRolesApi.md#list) | **GET** /pulp/api/v3/content/ansible/roles/ | List roles
*PulpAnsibleClient::ContentRolesApi* | [**read**](docs/ContentRolesApi.md#read) | **GET** {ansible_role_href} | Inspect a role
*PulpAnsibleClient::DistributionsAnsibleApi* | [**add_role**](docs/DistributionsAnsibleApi.md#add_role) | **POST** {ansible_ansible_distribution_href}add_role/ | Add a role
*PulpAnsibleClient::DistributionsAnsibleApi* | [**create**](docs/DistributionsAnsibleApi.md#create) | **POST** /pulp/api/v3/distributions/ansible/ansible/ | Create an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**delete**](docs/DistributionsAnsibleApi.md#delete) | **DELETE** {ansible_ansible_distribution_href} | Delete an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**list**](docs/DistributionsAnsibleApi.md#list) | **GET** /pulp/api/v3/distributions/ansible/ansible/ | List ansible distributions
*PulpAnsibleClient::DistributionsAnsibleApi* | [**list_roles**](docs/DistributionsAnsibleApi.md#list_roles) | **GET** {ansible_ansible_distribution_href}list_roles/ | List roles
*PulpAnsibleClient::DistributionsAnsibleApi* | [**my_permissions**](docs/DistributionsAnsibleApi.md#my_permissions) | **GET** {ansible_ansible_distribution_href}my_permissions/ | List user permissions
*PulpAnsibleClient::DistributionsAnsibleApi* | [**partial_update**](docs/DistributionsAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**read**](docs/DistributionsAnsibleApi.md#read) | **GET** {ansible_ansible_distribution_href} | Inspect an ansible distribution
*PulpAnsibleClient::DistributionsAnsibleApi* | [**remove_role**](docs/DistributionsAnsibleApi.md#remove_role) | **POST** {ansible_ansible_distribution_href}remove_role/ | Remove a role
*PulpAnsibleClient::DistributionsAnsibleApi* | [**set_label**](docs/DistributionsAnsibleApi.md#set_label) | **POST** {ansible_ansible_distribution_href}set_label/ | Set a label
*PulpAnsibleClient::DistributionsAnsibleApi* | [**unset_label**](docs/DistributionsAnsibleApi.md#unset_label) | **POST** {ansible_ansible_distribution_href}unset_label/ | Unset a label
*PulpAnsibleClient::DistributionsAnsibleApi* | [**update**](docs/DistributionsAnsibleApi.md#update) | **PUT** {ansible_ansible_distribution_href} | Update an ansible distribution
*PulpAnsibleClient::GalaxyDetailApi* | [**get**](docs/GalaxyDetailApi.md#get) | **GET** {ansible_collection_href} | 
*PulpAnsibleClient::PulpAnsibleApiApi* | [**get**](docs/PulpAnsibleApiApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/ | 
*PulpAnsibleClient::PulpAnsibleApiV2CollectionsVersionsApi* | [**get**](docs/PulpAnsibleApiV2CollectionsVersionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v2/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3Api* | [**read**](docs/PulpAnsibleApiV3Api.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/ | 
*PulpAnsibleClient::PulpAnsibleApiV3ArtifactsCollectionsApi* | [**get**](docs/PulpAnsibleApiV3ArtifactsCollectionsApi.md#get) | **GET** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/{path}/{filename} | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionVersionsAllApi* | [**list**](docs/PulpAnsibleApiV3CollectionVersionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collection_versions/all/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**delete**](docs/PulpAnsibleApiV3CollectionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**list**](docs/PulpAnsibleApiV3CollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**read**](docs/PulpAnsibleApiV3CollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsApi* | [**update**](docs/PulpAnsibleApiV3CollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsAllApi* | [**list**](docs/PulpAnsibleApiV3CollectionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/all/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**delete**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**list**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsApi* | [**read**](docs/PulpAnsibleApiV3CollectionsVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3CollectionsVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleApiV3CollectionsVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleApiV3NamespacesApi* | [**list**](docs/PulpAnsibleApiV3NamespacesApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleApiV3NamespacesApi* | [**read**](docs/PulpAnsibleApiV3NamespacesApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleClientConfigurationApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleClientConfigurationApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/client-configuration/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsAllCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-collections/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsAllVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi* | [**download**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsArtifactsApi.md#download) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/{filename} | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**delete**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi* | [**update**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexApi.md#update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**delete**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentNamespacesApi* | [**create**](docs/PulpAnsibleApiV3PluginAnsibleContentNamespacesApi.md#create) | **POST** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentNamespacesApi* | [**delete**](docs/PulpAnsibleApiV3PluginAnsibleContentNamespacesApi.md#delete) | **DELETE** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentNamespacesApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleContentNamespacesApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentNamespacesApi* | [**partial_update**](docs/PulpAnsibleApiV3PluginAnsibleContentNamespacesApi.md#partial_update) | **PATCH** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleContentNamespacesApi* | [**read**](docs/PulpAnsibleApiV3PluginAnsibleContentNamespacesApi.md#read) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleSearchCollectionVersionsApi* | [**list**](docs/PulpAnsibleApiV3PluginAnsibleSearchCollectionVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/search/collection-versions/ | 
*PulpAnsibleClient::PulpAnsibleApiV3PluginAnsibleSearchCollectionVersionsApi* | [**rebuild**](docs/PulpAnsibleApiV3PluginAnsibleSearchCollectionVersionsApi.md#rebuild) | **POST** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/search/collection-versions/ | 
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create) | **POST** /pulp_ansible/galaxy/{path}/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_0**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_0) | **POST** /pulp_ansible/galaxy/{path}/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_1**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_1) | **POST** /pulp_ansible/galaxy/default/api/v3/artifacts/collections/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleArtifactsCollectionsV3Api* | [**create_2**](docs/PulpAnsibleArtifactsCollectionsV3Api.md#create_2) | **POST** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/ | Upload a collection
*PulpAnsibleClient::PulpAnsibleDefaultApiApi* | [**get**](docs/PulpAnsibleDefaultApiApi.md#get) | **GET** /pulp_ansible/galaxy/default/api/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3Api* | [**read**](docs/PulpAnsibleDefaultApiV3Api.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3ArtifactsCollectionsApi* | [**get**](docs/PulpAnsibleDefaultApiV3ArtifactsCollectionsApi.md#get) | **GET** /pulp_ansible/galaxy/default/api/v3/artifacts/collections/{path}/{filename} | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionVersionsAllApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionVersionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collection_versions/all/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsApi* | [**update**](docs/PulpAnsibleDefaultApiV3CollectionsApi.md#update) | **PATCH** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsAllApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsAllApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/all/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleDefaultApiV3CollectionsVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/collections/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3NamespacesApi* | [**list**](docs/PulpAnsibleDefaultApiV3NamespacesApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3NamespacesApi* | [**read**](docs/PulpAnsibleDefaultApiV3NamespacesApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleClientConfigurationApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/client-configuration/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllCollectionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-collections/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsAllVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/all-versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi* | [**download**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsArtifactsApi.md#download) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/artifacts/{filename} | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**delete**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi* | [**update**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexApi.md#update) | **PATCH** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**delete**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentCollectionsIndexVersionsDocsBlobApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/collections/index/{namespace}/{name}/versions/{version}/docs-blob/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi* | [**create**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi.md#create) | **POST** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi* | [**delete**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi.md#delete) | **DELETE** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi* | [**partial_update**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi.md#partial_update) | **PATCH** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi* | [**read**](docs/PulpAnsibleDefaultApiV3PluginAnsibleContentNamespacesApi.md#read) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/content/{distro_base_path}/namespaces/{name}/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi* | [**list**](docs/PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi.md#list) | **GET** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/search/collection-versions/ | 
*PulpAnsibleClient::PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi* | [**rebuild**](docs/PulpAnsibleDefaultApiV3PluginAnsibleSearchCollectionVersionsApi.md#rebuild) | **POST** /pulp_ansible/galaxy/default/api/v3/plugin/ansible/search/collection-versions/ | 
*PulpAnsibleClient::PulpAnsibleTagsApi* | [**list**](docs/PulpAnsibleTagsApi.md#list) | **GET** /pulp/api/v3/pulp_ansible/tags/ | List tags
*PulpAnsibleClient::RemotesCollectionApi* | [**add_role**](docs/RemotesCollectionApi.md#add_role) | **POST** {ansible_collection_remote_href}add_role/ | Add a role
*PulpAnsibleClient::RemotesCollectionApi* | [**create**](docs/RemotesCollectionApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/collection/ | Create a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**delete**](docs/RemotesCollectionApi.md#delete) | **DELETE** {ansible_collection_remote_href} | Delete a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**list**](docs/RemotesCollectionApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/collection/ | List collection remotes
*PulpAnsibleClient::RemotesCollectionApi* | [**list_roles**](docs/RemotesCollectionApi.md#list_roles) | **GET** {ansible_collection_remote_href}list_roles/ | List roles
*PulpAnsibleClient::RemotesCollectionApi* | [**my_permissions**](docs/RemotesCollectionApi.md#my_permissions) | **GET** {ansible_collection_remote_href}my_permissions/ | List user permissions
*PulpAnsibleClient::RemotesCollectionApi* | [**partial_update**](docs/RemotesCollectionApi.md#partial_update) | **PATCH** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**read**](docs/RemotesCollectionApi.md#read) | **GET** {ansible_collection_remote_href} | Inspect a collection remote
*PulpAnsibleClient::RemotesCollectionApi* | [**remove_role**](docs/RemotesCollectionApi.md#remove_role) | **POST** {ansible_collection_remote_href}remove_role/ | Remove a role
*PulpAnsibleClient::RemotesCollectionApi* | [**set_label**](docs/RemotesCollectionApi.md#set_label) | **POST** {ansible_collection_remote_href}set_label/ | Set a label
*PulpAnsibleClient::RemotesCollectionApi* | [**unset_label**](docs/RemotesCollectionApi.md#unset_label) | **POST** {ansible_collection_remote_href}unset_label/ | Unset a label
*PulpAnsibleClient::RemotesCollectionApi* | [**update**](docs/RemotesCollectionApi.md#update) | **PUT** {ansible_collection_remote_href} | Update a collection remote
*PulpAnsibleClient::RemotesGitApi* | [**add_role**](docs/RemotesGitApi.md#add_role) | **POST** {ansible_git_remote_href}add_role/ | Add a role
*PulpAnsibleClient::RemotesGitApi* | [**create**](docs/RemotesGitApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/git/ | Create a git remote
*PulpAnsibleClient::RemotesGitApi* | [**delete**](docs/RemotesGitApi.md#delete) | **DELETE** {ansible_git_remote_href} | Delete a git remote
*PulpAnsibleClient::RemotesGitApi* | [**list**](docs/RemotesGitApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/git/ | List git remotes
*PulpAnsibleClient::RemotesGitApi* | [**list_roles**](docs/RemotesGitApi.md#list_roles) | **GET** {ansible_git_remote_href}list_roles/ | List roles
*PulpAnsibleClient::RemotesGitApi* | [**my_permissions**](docs/RemotesGitApi.md#my_permissions) | **GET** {ansible_git_remote_href}my_permissions/ | List user permissions
*PulpAnsibleClient::RemotesGitApi* | [**partial_update**](docs/RemotesGitApi.md#partial_update) | **PATCH** {ansible_git_remote_href} | Update a git remote
*PulpAnsibleClient::RemotesGitApi* | [**read**](docs/RemotesGitApi.md#read) | **GET** {ansible_git_remote_href} | Inspect a git remote
*PulpAnsibleClient::RemotesGitApi* | [**remove_role**](docs/RemotesGitApi.md#remove_role) | **POST** {ansible_git_remote_href}remove_role/ | Remove a role
*PulpAnsibleClient::RemotesGitApi* | [**set_label**](docs/RemotesGitApi.md#set_label) | **POST** {ansible_git_remote_href}set_label/ | Set a label
*PulpAnsibleClient::RemotesGitApi* | [**unset_label**](docs/RemotesGitApi.md#unset_label) | **POST** {ansible_git_remote_href}unset_label/ | Unset a label
*PulpAnsibleClient::RemotesGitApi* | [**update**](docs/RemotesGitApi.md#update) | **PUT** {ansible_git_remote_href} | Update a git remote
*PulpAnsibleClient::RemotesRoleApi* | [**add_role**](docs/RemotesRoleApi.md#add_role) | **POST** {ansible_role_remote_href}add_role/ | Add a role
*PulpAnsibleClient::RemotesRoleApi* | [**create**](docs/RemotesRoleApi.md#create) | **POST** /pulp/api/v3/remotes/ansible/role/ | Create a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**delete**](docs/RemotesRoleApi.md#delete) | **DELETE** {ansible_role_remote_href} | Delete a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**list**](docs/RemotesRoleApi.md#list) | **GET** /pulp/api/v3/remotes/ansible/role/ | List role remotes
*PulpAnsibleClient::RemotesRoleApi* | [**list_roles**](docs/RemotesRoleApi.md#list_roles) | **GET** {ansible_role_remote_href}list_roles/ | List roles
*PulpAnsibleClient::RemotesRoleApi* | [**my_permissions**](docs/RemotesRoleApi.md#my_permissions) | **GET** {ansible_role_remote_href}my_permissions/ | List user permissions
*PulpAnsibleClient::RemotesRoleApi* | [**partial_update**](docs/RemotesRoleApi.md#partial_update) | **PATCH** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**read**](docs/RemotesRoleApi.md#read) | **GET** {ansible_role_remote_href} | Inspect a role remote
*PulpAnsibleClient::RemotesRoleApi* | [**remove_role**](docs/RemotesRoleApi.md#remove_role) | **POST** {ansible_role_remote_href}remove_role/ | Remove a role
*PulpAnsibleClient::RemotesRoleApi* | [**set_label**](docs/RemotesRoleApi.md#set_label) | **POST** {ansible_role_remote_href}set_label/ | Set a label
*PulpAnsibleClient::RemotesRoleApi* | [**unset_label**](docs/RemotesRoleApi.md#unset_label) | **POST** {ansible_role_remote_href}unset_label/ | Unset a label
*PulpAnsibleClient::RemotesRoleApi* | [**update**](docs/RemotesRoleApi.md#update) | **PUT** {ansible_role_remote_href} | Update a role remote
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**add_role**](docs/RepositoriesAnsibleApi.md#add_role) | **POST** {ansible_ansible_repository_href}add_role/ | Add a role
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**copy_collection_version**](docs/RepositoriesAnsibleApi.md#copy_collection_version) | **POST** {ansible_ansible_repository_href}copy_collection_version/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**create**](docs/RepositoriesAnsibleApi.md#create) | **POST** /pulp/api/v3/repositories/ansible/ansible/ | Create an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**delete**](docs/RepositoriesAnsibleApi.md#delete) | **DELETE** {ansible_ansible_repository_href} | Delete an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**list**](docs/RepositoriesAnsibleApi.md#list) | **GET** /pulp/api/v3/repositories/ansible/ansible/ | List ansible repositorys
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**list_roles**](docs/RepositoriesAnsibleApi.md#list_roles) | **GET** {ansible_ansible_repository_href}list_roles/ | List roles
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**mark**](docs/RepositoriesAnsibleApi.md#mark) | **POST** {ansible_ansible_repository_href}mark/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**modify**](docs/RepositoriesAnsibleApi.md#modify) | **POST** {ansible_ansible_repository_href}modify/ | Modify Repository Content
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**move_collection_version**](docs/RepositoriesAnsibleApi.md#move_collection_version) | **POST** {ansible_ansible_repository_href}move_collection_version/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**my_permissions**](docs/RepositoriesAnsibleApi.md#my_permissions) | **GET** {ansible_ansible_repository_href}my_permissions/ | List user permissions
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**partial_update**](docs/RepositoriesAnsibleApi.md#partial_update) | **PATCH** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**read**](docs/RepositoriesAnsibleApi.md#read) | **GET** {ansible_ansible_repository_href} | Inspect an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**rebuild_metadata**](docs/RepositoriesAnsibleApi.md#rebuild_metadata) | **POST** {ansible_ansible_repository_href}rebuild_metadata/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**remove_role**](docs/RepositoriesAnsibleApi.md#remove_role) | **POST** {ansible_ansible_repository_href}remove_role/ | Remove a role
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**set_label**](docs/RepositoriesAnsibleApi.md#set_label) | **POST** {ansible_ansible_repository_href}set_label/ | Set a label
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**sign**](docs/RepositoriesAnsibleApi.md#sign) | **POST** {ansible_ansible_repository_href}sign/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**sync**](docs/RepositoriesAnsibleApi.md#sync) | **POST** {ansible_ansible_repository_href}sync/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**unmark**](docs/RepositoriesAnsibleApi.md#unmark) | **POST** {ansible_ansible_repository_href}unmark/ | 
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**unset_label**](docs/RepositoriesAnsibleApi.md#unset_label) | **POST** {ansible_ansible_repository_href}unset_label/ | Unset a label
*PulpAnsibleClient::RepositoriesAnsibleApi* | [**update**](docs/RepositoriesAnsibleApi.md#update) | **PUT** {ansible_ansible_repository_href} | Update an ansible repository
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**delete**](docs/RepositoriesAnsibleVersionsApi.md#delete) | **DELETE** {ansible_ansible_repository_version_href} | Delete a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**list**](docs/RepositoriesAnsibleVersionsApi.md#list) | **GET** {ansible_ansible_repository_href}versions/ | List repository versions
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**read**](docs/RepositoriesAnsibleVersionsApi.md#read) | **GET** {ansible_ansible_repository_version_href} | Inspect a repository version
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**rebuild_metadata**](docs/RepositoriesAnsibleVersionsApi.md#rebuild_metadata) | **POST** {ansible_ansible_repository_version_href}rebuild_metadata/ | 
*PulpAnsibleClient::RepositoriesAnsibleVersionsApi* | [**repair**](docs/RepositoriesAnsibleVersionsApi.md#repair) | **POST** {ansible_ansible_repository_version_href}repair/ | 
*PulpAnsibleClient::VersionsApi* | [**api_v1_roles_versions_list**](docs/VersionsApi.md#api_v1_roles_versions_list) | **GET** {ansible_role_href}versions/ | 
*PulpAnsibleClient::VersionsApi* | [**api_v2_collection_versions_list**](docs/VersionsApi.md#api_v2_collection_versions_list) | **GET** {ansible_collection_version_href}versions/ | 


## Documentation for Models

 - [PulpAnsibleClient::AnsibleAnsibleDistribution](docs/AnsibleAnsibleDistribution.md)
 - [PulpAnsibleClient::AnsibleAnsibleDistributionResponse](docs/AnsibleAnsibleDistributionResponse.md)
 - [PulpAnsibleClient::AnsibleAnsibleNamespaceMetadata](docs/AnsibleAnsibleNamespaceMetadata.md)
 - [PulpAnsibleClient::AnsibleAnsibleNamespaceMetadataResponse](docs/AnsibleAnsibleNamespaceMetadataResponse.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepository](docs/AnsibleAnsibleRepository.md)
 - [PulpAnsibleClient::AnsibleAnsibleRepositoryResponse](docs/AnsibleAnsibleRepositoryResponse.md)
 - [PulpAnsibleClient::AnsibleCollection](docs/AnsibleCollection.md)
 - [PulpAnsibleClient::AnsibleCollectionRemote](docs/AnsibleCollectionRemote.md)
 - [PulpAnsibleClient::AnsibleCollectionRemoteResponse](docs/AnsibleCollectionRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionRemoteResponseHiddenFields](docs/AnsibleCollectionRemoteResponseHiddenFields.md)
 - [PulpAnsibleClient::AnsibleCollectionResponse](docs/AnsibleCollectionResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersion](docs/AnsibleCollectionVersion.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionMark](docs/AnsibleCollectionVersionMark.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionMarkResponse](docs/AnsibleCollectionVersionMarkResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionResponse](docs/AnsibleCollectionVersionResponse.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionSignature](docs/AnsibleCollectionVersionSignature.md)
 - [PulpAnsibleClient::AnsibleCollectionVersionSignatureResponse](docs/AnsibleCollectionVersionSignatureResponse.md)
 - [PulpAnsibleClient::AnsibleGitRemote](docs/AnsibleGitRemote.md)
 - [PulpAnsibleClient::AnsibleGitRemoteResponse](docs/AnsibleGitRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleRepositoryMark](docs/AnsibleRepositoryMark.md)
 - [PulpAnsibleClient::AnsibleRepositoryRebuild](docs/AnsibleRepositoryRebuild.md)
 - [PulpAnsibleClient::AnsibleRepositorySignature](docs/AnsibleRepositorySignature.md)
 - [PulpAnsibleClient::AnsibleRepositorySyncURL](docs/AnsibleRepositorySyncURL.md)
 - [PulpAnsibleClient::AnsibleRole](docs/AnsibleRole.md)
 - [PulpAnsibleClient::AnsibleRoleRemote](docs/AnsibleRoleRemote.md)
 - [PulpAnsibleClient::AnsibleRoleRemoteResponse](docs/AnsibleRoleRemoteResponse.md)
 - [PulpAnsibleClient::AnsibleRoleResponse](docs/AnsibleRoleResponse.md)
 - [PulpAnsibleClient::AnsibleTagResponse](docs/AnsibleTagResponse.md)
 - [PulpAnsibleClient::ArtifactRefResponse](docs/ArtifactRefResponse.md)
 - [PulpAnsibleClient::AsyncOperationResponse](docs/AsyncOperationResponse.md)
 - [PulpAnsibleClient::ClientConfigurationResponse](docs/ClientConfigurationResponse.md)
 - [PulpAnsibleClient::CollectionImportDetailResponse](docs/CollectionImportDetailResponse.md)
 - [PulpAnsibleClient::CollectionMetadataResponse](docs/CollectionMetadataResponse.md)
 - [PulpAnsibleClient::CollectionNamespaceResponse](docs/CollectionNamespaceResponse.md)
 - [PulpAnsibleClient::CollectionOneShot](docs/CollectionOneShot.md)
 - [PulpAnsibleClient::CollectionRefResponse](docs/CollectionRefResponse.md)
 - [PulpAnsibleClient::CollectionResponse](docs/CollectionResponse.md)
 - [PulpAnsibleClient::CollectionSummaryResponse](docs/CollectionSummaryResponse.md)
 - [PulpAnsibleClient::CollectionVersionCopyMove](docs/CollectionVersionCopyMove.md)
 - [PulpAnsibleClient::CollectionVersionDocsResponse](docs/CollectionVersionDocsResponse.md)
 - [PulpAnsibleClient::CollectionVersionListResponse](docs/CollectionVersionListResponse.md)
 - [PulpAnsibleClient::CollectionVersionResponse](docs/CollectionVersionResponse.md)
 - [PulpAnsibleClient::CollectionVersionSearchList](docs/CollectionVersionSearchList.md)
 - [PulpAnsibleClient::CollectionVersionSearchListResponse](docs/CollectionVersionSearchListResponse.md)
 - [PulpAnsibleClient::CollectionVersionSignatureResponse](docs/CollectionVersionSignatureResponse.md)
 - [PulpAnsibleClient::ContentSummaryResponse](docs/ContentSummaryResponse.md)
 - [PulpAnsibleClient::Copy](docs/Copy.md)
 - [PulpAnsibleClient::GalaxyCollection](docs/GalaxyCollection.md)
 - [PulpAnsibleClient::GalaxyCollectionResponse](docs/GalaxyCollectionResponse.md)
 - [PulpAnsibleClient::GalaxyCollectionVersionResponse](docs/GalaxyCollectionVersionResponse.md)
 - [PulpAnsibleClient::GalaxyRoleResponse](docs/GalaxyRoleResponse.md)
 - [PulpAnsibleClient::GalaxyRoleVersionResponse](docs/GalaxyRoleVersionResponse.md)
 - [PulpAnsibleClient::MyPermissionsResponse](docs/MyPermissionsResponse.md)
 - [PulpAnsibleClient::NamespaceLink](docs/NamespaceLink.md)
 - [PulpAnsibleClient::NamespaceLinkResponse](docs/NamespaceLinkResponse.md)
 - [PulpAnsibleClient::NestedRole](docs/NestedRole.md)
 - [PulpAnsibleClient::NestedRoleResponse](docs/NestedRoleResponse.md)
 - [PulpAnsibleClient::ObjectRolesResponse](docs/ObjectRolesResponse.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseList](docs/PaginatedCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseListLinks](docs/PaginatedCollectionResponseListLinks.md)
 - [PulpAnsibleClient::PaginatedCollectionResponseListMeta](docs/PaginatedCollectionResponseListMeta.md)
 - [PulpAnsibleClient::PaginatedCollectionVersionListResponseList](docs/PaginatedCollectionVersionListResponseList.md)
 - [PulpAnsibleClient::PaginatedCollectionVersionSearchListResponseList](docs/PaginatedCollectionVersionSearchListResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionResponseList](docs/PaginatedGalaxyCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyCollectionVersionResponseList](docs/PaginatedGalaxyCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleResponseList](docs/PaginatedGalaxyRoleResponseList.md)
 - [PulpAnsibleClient::PaginatedGalaxyRoleVersionResponseList](docs/PaginatedGalaxyRoleVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedRepositoryVersionResponseList](docs/PaginatedRepositoryVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedTagResponseList](docs/PaginatedTagResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleDistributionResponseList](docs/PaginatedansibleAnsibleDistributionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleNamespaceMetadataResponseList](docs/PaginatedansibleAnsibleNamespaceMetadataResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleAnsibleRepositoryResponseList](docs/PaginatedansibleAnsibleRepositoryResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionRemoteResponseList](docs/PaginatedansibleCollectionRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionResponseList](docs/PaginatedansibleCollectionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionMarkResponseList](docs/PaginatedansibleCollectionVersionMarkResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionResponseList](docs/PaginatedansibleCollectionVersionResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleCollectionVersionSignatureResponseList](docs/PaginatedansibleCollectionVersionSignatureResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleGitRemoteResponseList](docs/PaginatedansibleGitRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleRemoteResponseList](docs/PaginatedansibleRoleRemoteResponseList.md)
 - [PulpAnsibleClient::PaginatedansibleRoleResponseList](docs/PaginatedansibleRoleResponseList.md)
 - [PulpAnsibleClient::PatchedCollection](docs/PatchedCollection.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleDistribution](docs/PatchedansibleAnsibleDistribution.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleNamespaceMetadata](docs/PatchedansibleAnsibleNamespaceMetadata.md)
 - [PulpAnsibleClient::PatchedansibleAnsibleRepository](docs/PatchedansibleAnsibleRepository.md)
 - [PulpAnsibleClient::PatchedansibleCollectionRemote](docs/PatchedansibleCollectionRemote.md)
 - [PulpAnsibleClient::PatchedansibleGitRemote](docs/PatchedansibleGitRemote.md)
 - [PulpAnsibleClient::PatchedansibleRoleRemote](docs/PatchedansibleRoleRemote.md)
 - [PulpAnsibleClient::PolicyEnum](docs/PolicyEnum.md)
 - [PulpAnsibleClient::Repair](docs/Repair.md)
 - [PulpAnsibleClient::RepoMetadataResponse](docs/RepoMetadataResponse.md)
 - [PulpAnsibleClient::Repository](docs/Repository.md)
 - [PulpAnsibleClient::RepositoryAddRemoveContent](docs/RepositoryAddRemoveContent.md)
 - [PulpAnsibleClient::RepositoryResponse](docs/RepositoryResponse.md)
 - [PulpAnsibleClient::RepositoryVersionResponse](docs/RepositoryVersionResponse.md)
 - [PulpAnsibleClient::SetLabel](docs/SetLabel.md)
 - [PulpAnsibleClient::SetLabelResponse](docs/SetLabelResponse.md)
 - [PulpAnsibleClient::TagResponse](docs/TagResponse.md)
 - [PulpAnsibleClient::UnpaginatedCollectionVersionResponse](docs/UnpaginatedCollectionVersionResponse.md)
 - [PulpAnsibleClient::UnsetLabel](docs/UnsetLabel.md)
 - [PulpAnsibleClient::UnsetLabelResponse](docs/UnsetLabelResponse.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication

