# PulpAnsibleClient::ContentCollectionMarksApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentCollectionMarksApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_marks/ | Create a collection version mark
[**list**](ContentCollectionMarksApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_marks/ | List collection version marks
[**read**](ContentCollectionMarksApi.md#read) | **GET** {ansible_collection_version_mark_href} | Inspect a collection version mark



## create

> AnsibleCollectionVersionMarkResponse create(ansible_collection_version_mark)

Create a collection version mark

ViewSet for looking at mark objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionMarksApi.new
ansible_collection_version_mark = PulpAnsibleClient::AnsibleCollectionVersionMark.new # AnsibleCollectionVersionMark | 

begin
  #Create a collection version mark
  result = api_instance.create(ansible_collection_version_mark)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionMarksApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_collection_version_mark** | [**AnsibleCollectionVersionMark**](AnsibleCollectionVersionMark.md)|  | 

### Return type

[**AnsibleCollectionVersionMarkResponse**](AnsibleCollectionVersionMarkResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json


## list

> PaginatedansibleCollectionVersionMarkResponseList list(opts)

List collection version marks

ViewSet for looking at mark objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionMarksApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  marked_collection: 'marked_collection_example', # String | Filter marks for collection version
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `value` - Value * `-value` - Value (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  value: 'value_example', # String | Filter marks by value
  value__in: ['value__in_example'], # Array<String> | Filter results where value is in a comma-separated list of values
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List collection version marks
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionMarksApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **marked_collection** | [**String**](.md)| Filter marks for collection version | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;value&#x60; - Value * &#x60;-value&#x60; - Value (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **value** | **String**| Filter marks by value | [optional] 
 **value__in** | [**Array&lt;String&gt;**](String.md)| Filter results where value is in a comma-separated list of values | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedansibleCollectionVersionMarkResponseList**](PaginatedansibleCollectionVersionMarkResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> AnsibleCollectionVersionMarkResponse read(ansible_collection_version_mark_href, opts)

Inspect a collection version mark

ViewSet for looking at mark objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionMarksApi.new
ansible_collection_version_mark_href = 'ansible_collection_version_mark_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a collection version mark
  result = api_instance.read(ansible_collection_version_mark_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionMarksApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_collection_version_mark_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleCollectionVersionMarkResponse**](AnsibleCollectionVersionMarkResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

