# PulpAnsibleClient::ContentCollectionSignaturesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create**](ContentCollectionSignaturesApi.md#create) | **POST** /pulp/api/v3/content/ansible/collection_signatures/ | Create a collection version signature
[**list**](ContentCollectionSignaturesApi.md#list) | **GET** /pulp/api/v3/content/ansible/collection_signatures/ | List collection version signatures
[**read**](ContentCollectionSignaturesApi.md#read) | **GET** {ansible_collection_version_signature_href} | Inspect a collection version signature



## create

> AsyncOperationResponse create(file, signed_collection, opts)

Create a collection version signature

Trigger an asynchronous task to create content,optionally create new repository version.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionSignaturesApi.new
file = File.new('/path/to/file') # File | An uploaded file that may be turned into the artifact of the content unit.
signed_collection = 'signed_collection_example' # String | The content this signature is pointing to.
opts = {
  repository: 'repository_example' # String | A URI of a repository the new content unit should be associated with.
}

begin
  #Create a collection version signature
  result = api_instance.create(file, signed_collection, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionSignaturesApi->create: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file** | **File**| An uploaded file that may be turned into the artifact of the content unit. | 
 **signed_collection** | **String**| The content this signature is pointing to. | 
 **repository** | **String**| A URI of a repository the new content unit should be associated with. | [optional] 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: multipart/form-data, application/x-www-form-urlencoded
- **Accept**: application/json


## list

> PaginatedansibleCollectionVersionSignatureResponseList list(opts)

List collection version signatures

ViewSet for looking at signature objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionSignaturesApi.new
opts = {
  limit: 56, # Integer | Number of results to return per page.
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `data` - Data * `-data` - Data (descending) * `digest` - Digest * `-digest` - Digest (descending) * `pubkey_fingerprint` - Pubkey fingerprint * `-pubkey_fingerprint` - Pubkey fingerprint (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pubkey_fingerprint: 'pubkey_fingerprint_example', # String | Filter results where pubkey_fingerprint matches value
  pubkey_fingerprint__in: ['pubkey_fingerprint__in_example'], # Array<String> | Filter results where pubkey_fingerprint is in a comma-separated list of values
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  signed_collection: 'signed_collection_example', # String | Filter signatures for collection version
  signing_service: 'signing_service_example', # String | Filter signatures produced by signature service
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List collection version signatures
  result = api_instance.list(opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionSignaturesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;data&#x60; - Data * &#x60;-data&#x60; - Data (descending) * &#x60;digest&#x60; - Digest * &#x60;-digest&#x60; - Digest (descending) * &#x60;pubkey_fingerprint&#x60; - Pubkey fingerprint * &#x60;-pubkey_fingerprint&#x60; - Pubkey fingerprint (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pubkey_fingerprint** | **String**| Filter results where pubkey_fingerprint matches value | [optional] 
 **pubkey_fingerprint__in** | [**Array&lt;String&gt;**](String.md)| Filter results where pubkey_fingerprint is in a comma-separated list of values | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **signed_collection** | [**String**](.md)| Filter signatures for collection version | [optional] 
 **signing_service** | [**String**](.md)| Filter signatures produced by signature service | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedansibleCollectionVersionSignatureResponseList**](PaginatedansibleCollectionVersionSignatureResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> AnsibleCollectionVersionSignatureResponse read(ansible_collection_version_signature_href, opts)

Inspect a collection version signature

ViewSet for looking at signature objects for CollectionVersion content.

### Example

```ruby
# load the gem
require 'pulp_ansible_client'
# setup authorization
PulpAnsibleClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpAnsibleClient::ContentCollectionSignaturesApi.new
ansible_collection_version_signature_href = 'ansible_collection_version_signature_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a collection version signature
  result = api_instance.read(ansible_collection_version_signature_href, opts)
  p result
rescue PulpAnsibleClient::ApiError => e
  puts "Exception when calling ContentCollectionSignaturesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ansible_collection_version_signature_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**AnsibleCollectionVersionSignatureResponse**](AnsibleCollectionVersionSignatureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

